# pylat

<table>
<tr>
  <td>Latest Release</td>
  <td>
    <a href="https://pypi.org/project/pylat/">
    <img src="https://badge.fury.io/py/pylat.svg" alt="latest release" />
    </a>
  </td>
<tr>
  <td>Package Status</td>
  <td>
		<a href="https://pypi.org/project/pylat/">
		<img src="https://img.shields.io/pypi/status/pandas.svg" alt="status" />
		</a>
  </td>
</tr>
<tr>
  <td>License</td>
  <td>
    <a href="https://github.com/weso/pylat/blob/master/LICENSE">
    <img src="https://img.shields.io/github/license/weso/pylat.svg" alt="license" />
    </a>
</td>
</tr>
<tr>
  <td>Build Status</td>
  <td>
    <a href="https://travis-ci.org/weso/pylat">
    <img src="https://travis-ci.org/weso/pylat.svg?branch=master" alt="travis build status" />
    </a>
  </td>
</tr>
<tr>
  <td>Coverage</td>
  <td>
    <a href="https://codecov.io/gh/weso/pylat">
    <img src="https://codecov.io/gh/weso/pylat/branch/master/graph/badge.svg" alt="coverage" />
    </a>
  </td>
</tr>
</table>

## What is it?
**pylat** is a Python package that provides an easy way to create machine learning models that work with textual data.
It contains utilities to handle all the common steps needed in every NLP project, so developers don't need to reinvent
the wheel and can set up their projects quickly.

## Main Features
Here are just a few of the main features of pylat:
* Classes to easily manage document and word embeddings, including multilingual word embeddings.
* Implementation of a Recurrent Neural Network in Tensorflow, which can be easily customizable to meet the needs of each developer.
* Easy integration with existing sklearn classes and pipelines.
* Preprocessing of texts with Spacy.
* More feature extraction tools.
* Methods to perform statistical tests between classifiers.

## Installation
The pylat library is available on PyPi and can be easily installed using the pip package manager using the following command:

``
pip install pylat
``

## License
[GPL-3](LICENSE)

## Documentation
The official documentation will be hosted at ReadTheDocs.org
